@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.4 1999/07/26 04:05:31 spapadim Exp $ */
+/* $Id: gweather-dialog.c,v 1.5 2000/01/28 21:20:25 tgil Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -48,11 +48,17 @@ static GdkBitmap *mask = NULL;
 static void close_cb (GtkButton *button, gpointer data)
 {
     gweather_dialog_close();
+    return;
+    button = NULL;
+    data = NULL;
 }
 
 static void link_cb (GtkButton *button, gpointer data)
 {
     gnome_url_show("http://www.weather.com/");
+    return;
+    button = NULL;
+    data = NULL;
 }
 
 void gweather_dialog_create (void)
