@@ -98,9 +98,16 @@ static gint setup_done = FALSE;
 
 static void about_cb (AppletWidget *widget, gpointer data)
 {
-	GtkWidget *about;
+	static GtkWidget *about = NULL;
 	const gchar *authors[8];
 
+	if (about != NULL)
+	{
+		gdk_window_show(about->window);
+		gdk_window_raise(about->window);
+		return;
+	}
+
 	authors[0] = "John Ellis <johne@bellatlantic.net>";
 	authors[1] = "Martin Baulig <martin@home-of-linux.org> - ISDN";
 	authors[2] = NULL;
@@ -112,6 +119,8 @@ static void about_cb (AppletWidget *widget, gpointer data)
 			"A modem status indicator and dialer.\n"
 			"Lights in order from the top or left are Send data and Receive data."),
 			NULL);
+	gtk_signal_connect( GTK_OBJECT(about), "destroy",
+			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
 	gtk_widget_show (about);
 	return;
 	widget = NULL;
@@ -1095,6 +1104,15 @@ static void applet_change_pixel_size(GtkWidget *w, int s, gpointer data)
 }
 #endif
 
+static void show_help_cb(AppletWidget *applet, gpointer data)
+{
+	static GnomeHelpMenuEntry help_entry = { NULL, "index.html"};
+
+	help_entry.name = gnome_app_id;
+    
+	gnome_help_display (NULL, &help_entry);
+}
+
 static gint applet_save_session(GtkWidget *widget, char *privcfgpath, char *globcfgpath)
 {
 	property_save(privcfgpath);
@@ -1208,12 +1226,18 @@ int main (int argc, char *argv[])
 					      _("Properties..."),
 					      property_show,
 					      NULL);
+
+	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
+					      "help",
+					      GNOME_STOCK_PIXMAP_HELP,
+					      _("Help..."),
+					      show_help_cb, NULL);
+
 	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
 					      "about",
 					      GNOME_STOCK_MENU_ABOUT,
 					      _("About..."),
 					      about_cb, NULL);
-
 	start_callback_update();
 
 	applet_widget_gtk_main();
